/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'font', 'sr-latn', {
	fontSize: {
		label: 'Veličina ',
		voiceLabel: 'Veličina slova',
		panelTitle: 'Veličina slova'
	},
	label: 'Font',
	panelTitle: 'Naziv fonta',
	voiceLabel: 'Font'
} );
